# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.contrib import admin
from django.conf.urls import url, patterns

from jmb.core.admin.options import ExtendibleModelAdmin

from jmb.locality_it import models

from admin_views import (
    import_region_istat_data, import_province_istat_data,
    import_locality_istat_data
)


class RegionAdmin(ExtendibleModelAdmin):

    list_display = ('get_edit_icon', 'name', 'code',)
    ordering = ('code',)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                ('name', 'code',),
            )
        }),
    )
    advanced_search_fields = (
        ('name__icontains',),
    )

    def get_urls(self):
        urls = super(RegionAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(
                r'^import_istat_data/$',
                self.admin_site.admin_view(import_region_istat_data),
                name='locality_it_region_import_data'
            ),
        )
        return my_urls + urls


class ProvinceAdmin(ExtendibleModelAdmin):

    list_display = ('get_edit_icon', 'name', 'code', 'abbr', 'region',)
    ordering = ('region__code',)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                ('name', 'abbr',),
                ('code', 'region'),
            )
        }),
    )
    advanced_search_fields = (
        ('name__icontains', 'code__exact', 'abbr__exact',  'region__exact',),
    )

    def get_urls(self):
        urls = super(ProvinceAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(
                r'^import_istat_data/$',
                self.admin_site.admin_view(import_province_istat_data),
                name='locality_it_province_import_data'
            ),
        )
        return my_urls + urls


class LocalityAdmin(ExtendibleModelAdmin):

    list_display = ('get_edit_icon', 'name', 'province', 'get_region', 'code', 'istat_code',)
    ordering = ('province__name',)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                ('name', 'code',),
                'province',
                ('istat_code',)
            )
        }),
    )

    advanced_search_fields = (
        ('name__icontains', 'province__exact', 'province__region__exact', 'code__exact',  'istat_code__exact',),
    )

    def get_filterset_class(self, request):
        admin_filterset = super(LocalityAdmin, self).get_filterset_class(request)
        admin_filterset.base_filters['province__region__exact'].label = _("Region")
        return admin_filterset

    def get_urls(self):
        urls = super(LocalityAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(
                r'^import_istat_data/$',
                self.admin_site.admin_view(import_locality_istat_data),
                name='locality_it_city_import_data'
            ),
        )
        return my_urls + urls


class ZipCodeAdmin(ExtendibleModelAdmin):

    list_display = ('get_edit_icon', 'code', 'get_region', 'get_province',)
    # ordering = ('province__name',)
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'code',
                'locality',
            )
        }),
    )
    advanced_search_fields = (
        ('code__istartswith', 'locality__province__region__exact', 'locality__province__exact', ),
    )

    def get_filterset_class(self, request):
        admin_filterset = super(ZipCodeAdmin, self).get_filterset_class(request)
        admin_filterset.base_filters['locality__province__region__exact'].label = _("Region")
        admin_filterset.base_filters['locality__province__exact'].label = _("Province")
        return admin_filterset



admin.site.register(models.Region, RegionAdmin)
admin.site.register(models.Province, ProvinceAdmin)
admin.site.register(models.Locality, LocalityAdmin)
admin.site.register(models.ZipCode, ZipCodeAdmin)
