# -*- coding: utf-8 -*-

from jmb.core.utils.data_import import XlsFile
from jmb.locality_it.models import Region, Province, Locality


class RegionImport(XlsFile):

    def __init__(self, model, filename=None, file_contents=None, auto=False, sheet_index=0, *args, **kwargs):
        super(RegionImport, self).__init__(
            filename=filename, file_contents=file_contents, auto=auto, sheet_index=sheet_index
        )
        self.model = model
        self.messages = dict()
        self.messages['inserted'] = 0
        self.messages['modified'] = 0
        self.messages['unmodified'] = 0
        self.messages['errors'] = []
        self.region_codes = []

    def do(self, row, kw, j):
        # # ESEMPIO
        # Row(
        # Codicerbartizione=1.0, CodiceNUTS12006=u'ITC', CodiceNUTS12010=u'ITC',
        # RipartizionegeograficaMaiuscolo=u'NORD-OVEST', Ripartizionegeografica=u'Nord-ovest',
        # Codiceregione=1.0, CodiceNUTS22006a=u'ITC1', CodiceNUTS22010a=u'ITC1',
        # DenominazioneregioneMaiuscolo=u'PIEMONTE', Denominazioneregione=u'Piemonte',
        # Codiceprovincia=2.0, CodiceNUTS32006=u'ITC12', CodiceNUTS32010=u'ITC12',
        # Denominazioneprovincia=u'Vercelli', Siglaautomobilistica=u'VC'
        # )

        if (
            str(row.Codiceregione) != ""
            and str(int(row.Codiceregione)) not in self.region_codes
        ):
            codice_regione = str(int(row.Codiceregione))
            try:
                region, created = Region.objects.update_or_create(
                    code=codice_regione, defaults=dict(name=row.Denominazioneregione)
                )
                if created:
                    self.messages['inserted'] += 1
                else:
                    self.messages['modified'] += 1

                # Insert in region_codes regions already managed
                self.region_codes.append(codice_regione)

            except Exception, ex:
                self.messages['errors'].append(
                    'regione: %s - %s' % (codice_regione, ex)
                )


class ProvinceImport(XlsFile):

    def __init__(self, model, filename=None, file_contents=None, auto=False, sheet_index=0, *args, **kwargs):
        super(ProvinceImport, self).__init__(
            filename=filename, file_contents=file_contents, auto=auto, sheet_index=sheet_index
        )
        self.model = model
        self.messages = dict()
        self.messages['inserted'] = 0
        self.messages['modified'] = 0
        self.messages['unmodified'] = 0
        self.messages['errors'] = []
        self.province_codes = []

    def do(self, row, kw, j):
        # # ESEMPIO

        # CAPOLUOGHI
        # ----------
        # Row(Codiceripartizione=1.0, CodiceNUTS12006=u'ITC', CodiceNUTS12010=u'ITC',
        # RipartizionegeograficaMaiuscolo=u'NORD-OVEST', Ripartizionegeografica=u'Nord-ovest',
        # Codiceregione=1.0, CodiceNUTS22006a=u'ITC1', CodiceNUTS22010a=u'ITC1',
        # DenominazioneregioneMaiuscolo=u'PIEMONTE', Denominazioneregione=u'Piemonte',
        # Codiceprovincia=1.0, CodiceCittMetropolitana=201.0, CodiceNUTS32006=u'ITC11',
        # CodiceNUTS32010=u'ITC11', Denominazioneprovincia=u'-', DenominazioneCittmetropolitana=u'Torino',
        # Siglaautomobilistica=u'TO')

        # PROVINCE
        # --------
        # Row(Codiceripartizione=1.0, CodiceNUTS12006=u'ITC', CodiceNUTS12010=u'ITC',
        # RipartizionegeograficaMaiuscolo=u'NORD-OVEST', Ripartizionegeografica=u'Nord-ovest',
        # Codiceregione=1.0, CodiceNUTS22006a=u'ITC1', CodiceNUTS22010a=u'ITC1',
        # DenominazioneregioneMaiuscolo=u'PIEMONTE', Denominazioneregione=u'Piemonte',
        # Codiceprovincia=2.0, CodiceCittMetropolitana=u'-', CodiceNUTS32006=u'ITC12',
        # CodiceNUTS32010=u'ITC12', Denominazioneprovincia=u'Vercelli', DenominazioneCittmetropolitana='',
        # Siglaautomobilistica=u'VC')

        if (
            str(row.Codiceprovincia) != ""
            and str(int(row.Codiceprovincia)) not in self.province_codes
        ):
            province_code = str(int(row.Codiceprovincia))
            name = row.Denominazioneprovincia if row.Denominazioneprovincia != '-' else row.DenominazioneCittmetropolitana
            try:
                province, created = Province.objects.update_or_create(
                    code=province_code, defaults=dict(
                        name=name,
                        region_id=str(int(row.Codiceregione)),
                        abbr=row.Siglaautomobilistica,
                    )
                )
                if created:
                    self.messages['inserted'] += 1
                else:
                    self.messages['modified'] += 1
                # Insert in province_codes provinces already managed
                self.province_codes.append(province_code)

            except Exception, ex:
                self.messages['errors'].append(
                    'provincia: %s regione: %s - %s' % (
                        province_code, str(int(row.Codiceregione)), ex
                    )
                )


class LocalityImport(XlsFile):

    def __init__(self, model, filename=None, file_contents=None, auto=False, sheet_index=0, *args, **kwargs):
        super(LocalityImport, self).__init__(
            filename=filename, file_contents=file_contents, auto=auto, sheet_index=sheet_index
        )
        self.model = model
        self.messages = dict()
        self.messages['inserted'] = 0
        self.messages['modified'] = 0
        self.messages['unmodified'] = 0
        self.messages['errors'] = []
        self.locality_codes = []

    def do(self, row, kw, j):
        # # ESEMPIO
        #Row(Ripartizionegeografica=u'Nord-ovest', CodiceNUTS22010=u'ITC1', CodiceNUTS32010=u'ITC11',
        # CodiceRegione=u'01', CodiceProvincia=u'001', CodiceCittMetropolitana=u'201',
        # NumeroprogressivoComune=u'001', CodiceIstatdelComuneformatoalfanumerico=1001.0,
        # CodiceIstatdelComuneformatonumerico=1001.0, CodiceIstatdelComunea107provinceformatonumerico=1001.0,
        # CodiceIstatdelComunea103provinceformatonumerico=1001.0, CodiceCatastale=u'A074',
        # Solodenominazioneinitaliano=u'Agli\xe8', Solodenominazioneintedesco='',
        # Comunecapoluogodiprovincia=0.0, Zonaaltimetrica=u'3', Altitudinedelcentrometri=315.0,
        # Comunelitoraneo=0.0, ComuneMontano=u'NM', Superficieterritorialekmqal09102011=13.146400000000002,
        # Popolazionelegale200121102001=2574.0, Popolazionelegale201109102011=2644.0)

        if (
            str(row.NumeroprogressivoComune) != ""
            and str(row.NumeroprogressivoComune) not in self.locality_codes
        ):
            locality_code = str(int(row.NumeroprogressivoComune))
            locality_istat_code = str(int(row.CodiceIstatdelComuneformatonumerico))
            try:
                locality, created = Locality.objects.update_or_create(
                    istat_code=locality_istat_code, code=locality_code,
                    defaults=dict(
                        name=row.Solodenominazioneinitaliano.title(),
                        province_id=str(int(row.CodiceProvincia)),
                    )
                )
                if created:
                    self.messages['inserted'] += 1
                else:
                    self.messages['modified'] += 1
                # Insert in locality_codes localities already managed
                self.locality_codes.append(locality_code)
            except Exception, ex:
                self.messages['errors'].append(
                    'comune: %s provincia: %s regione: %s - %s' %(
                        row.NumeroprogressivoComune, row.CodiceProvincia, row.CodiceRegione,
                        ex
                    )
                )