# -*- coding: utf-8 -*-

from django import template
from django.contrib import messages
from django.core.urlresolvers import reverse
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from django.utils.translation import ugettext as _
from django.http import HttpResponse
from django.shortcuts import redirect

from jmb.locality_it.models import Region, Province, Locality
from jmb.locality_it.admin_forms import (ImportRegionForm, ImportProvinceForm, ImportCityForm)
from jmb.locality_it.admin_import import RegionImport, ProvinceImport, LocalityImport


def import_region_istat_data(request, **kwargs):
    model = Region
    app_label = _('Locality_it')
    verbose_name = _('Region')

    template_name = 'import_region.html'
    breadcrumbs = (
        (_('Home'), '/admin/'),
        (_(app_label), '/admin/locality_it/'),
        (_(verbose_name), '/admin/locality_it/region/'),
    )

    if request.method == 'POST':
        form = ImportRegionForm(request.POST, request.FILES)
        if form.is_valid():
            file_source = form.cleaned_data['import_file']
            import_data = RegionImport(
                file_contents=file_source.read(), auto=True, model=model, **kwargs
            )
            import_data.read()
            if import_data.messages['inserted'] > 0:
                messages.success(request, "%s righe inserite correttamente" % import_data.messages['inserted'])
            if import_data.messages['modified'] > 0:
                messages.warning(request, "%s righe modificate correttamente" % import_data.messages['modified'])
            if import_data.messages['unmodified'] > 0:
                messages.info(request, "%s righe non modificate" % import_data.messages['unmodified'])
            if import_data.messages['errors']:
                for error in import_data.messages['errors']:
                    messages.error(request, error)
        else:
            messages.error(request, "Correggi l'errore qui sotto")
    else:
        form = ImportRegionForm()

    context = {
        'title': _('Import %s') % verbose_name,
        'app_label': app_label,
        'breadcrumbs': breadcrumbs,
        'import_form': form
    }
    context_instance = template.RequestContext(request)
    return render_to_response(
        [
            "admin/locality_it/region/%s" % template_name,
            "admin/locality_it/%s" % template_name,
            "admin/%s" % template_name
        ],
        context,
        context_instance=context_instance
    )


def import_province_istat_data(request, **kwargs):
    model = Province
    app_label = _('Locality_it')
    verbose_name = _('Province')

    template_name = 'import_province.html'
    breadcrumbs = (
        (_('Home'), '/admin/'),
        (_(app_label), '/admin/locality_it/'),
        (_(verbose_name), '/admin/locality_it/province/'),
    )

    if request.method == 'POST':
        form = ImportProvinceForm(request.POST, request.FILES)
        if form.is_valid():
            file_source = form.cleaned_data['import_file']
            import_data = ProvinceImport(
                file_contents=file_source.read(), auto=True, model=model, **kwargs
            )
            import_data.read()
            if import_data.messages['inserted'] > 0:
                messages.success(request, "%s righe inserite correttamente" % import_data.messages['inserted'])
            if import_data.messages['modified'] > 0:
                messages.warning(request, "%s righe modificate correttamente" % import_data.messages['modified'])
            if import_data.messages['unmodified'] > 0:
                messages.info(request, "%s righe non modificate" % import_data.messages['unmodified'])
            if import_data.messages['errors']:
                for error in import_data.messages['errors']:
                    messages.error(request, error)
        else:
            messages.error(request, "Correggi l'errore qui sotto")
    else:
        form = ImportProvinceForm()

    context = {
        'title': _('Import %s') % verbose_name,
        'app_label': app_label,
        'breadcrumbs': breadcrumbs,
        'import_form': form
    }
    context_instance = template.RequestContext(request)
    return render_to_response(
        [
            "admin/locality_it/province/%s" % template_name,
            "admin/locality_it/%s" % template_name,
            "admin/%s" % template_name
        ],
        context,
        context_instance=context_instance
    )


def import_locality_istat_data(request, **kwargs):
    model = Locality
    app_label = _('Locality_it')
    verbose_name = _('Locality')

    template_name = 'import_city.html'
    breadcrumbs = (
        (_('Home'), '/admin/'),
        (_(app_label), '/admin/locality_it/'),
        (_(verbose_name), '/admin/locality_it/locality/'),
    )
    if request.method == 'POST':
        form = ImportCityForm(request.POST, request.FILES)
        if form.is_valid():
            file_source = form.cleaned_data['import_file']
            import_data = LocalityImport(
                file_contents=file_source.read(), auto=True, model=model, **kwargs
            )
            import_data.read()
            if import_data.messages['inserted'] > 0:
                messages.success(request, "%s righe inserite correttamente" % import_data.messages['inserted'])
            if import_data.messages['modified'] > 0:
                messages.warning(request, "%s righe modificate correttamente" % import_data.messages['modified'])
            if import_data.messages['unmodified'] > 0:
                messages.info(request, "%s righe non modificate" % import_data.messages['unmodified'])
            if import_data.messages['errors']:
                for error in import_data.messages['errors']:
                    messages.error(request, error)
        else:
            messages.error(request, "Correggi l'errore qui sotto")
    else:
        form = ImportCityForm()

    context = {
        'title': _('Import %s') % verbose_name,
        'app_label': app_label,
        'breadcrumbs': breadcrumbs,
        'import_form': form
    }
    context_instance = template.RequestContext(request)
    return render_to_response(
        [
            "admin/locality_it/city/%s" % template_name,
            "admin/locality_it/%s" % template_name,
            "admin/%s" % template_name
        ],
        context,
        context_instance=context_instance
    )
