# -*- coding: utf-8 -*-

from rest_framework import serializers

from jmb.locality_it import models


class RegionSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Region
        fields = ('code', 'name')


class ProvinceSerializer(serializers.ModelSerializer):
    region_name = serializers.SerializerMethodField('get_region_name')
    region_code = serializers.SerializerMethodField('get_region_code')

    def get_region_name(self, obj):
        return obj.region.name

    def get_region_code(self, obj):
        return obj.region.code

    class Meta:
        model = models.Province
        fields = ('code', 'region_code', 'region_name', 'name', 'abbr')


class LocalitySerializer(serializers.ModelSerializer):
    region_name = serializers.SerializerMethodField('get_region_name')
    region_code = serializers.SerializerMethodField('get_region_code')
    province_name = serializers.SerializerMethodField('get_province_name')
    province_code = serializers.SerializerMethodField('get_province_code')

    def get_region_name(self, obj):
        return obj.province.region.name

    def get_region_code(self, obj):
        return obj.province.region.code

    def get_province_name(self, obj):
        return obj.province.name

    def get_province_code(self, obj):
        return obj.province.code

    class Meta:
        model = models.Locality
        fields = (
            'istat_code', 'code', 'region_code', 'region_name',
            'province_code', 'province_name', 'name')