# -*- coding: utf-8 -*-

from rest_framework.response import Response
from rest_framework.views import APIView

from jmb.locality_it import models
from jmb.locality_it.api import serializers


class RegionList(APIView):
    """
    List Regions
    """

    def get(self, request, format=None):
        regions = models.Region.objects.all()
        serializer = serializers.RegionSerializer(regions, many=True)
        return Response(serializer.data)


class ProvinceList(APIView):
    """
    List Provinces
    """

    def get(self, request, region_code=None,format=None):
        provinces = models.Province.objects.all()
        if region_code:
            provinces = provinces.filter(region__code__iexact=region_code)
        serializer = serializers.ProvinceSerializer(provinces, many=True)
        return Response(serializer.data)


class LocalityList(APIView):
    """
    List Localities
    """

    paginate_by = 20

    def get(self, request, region_code=None, province_code=None, format=None):
        localities = models.Locality.objects.all()
        if region_code:
            localities = localities.filter(province__region__code__iexact=region_code)
        if province_code:
            localities = localities.filter(province__code__iexact=province_code)
        serializer = serializers.LocalitySerializer(localities, many=True)
        return Response(serializer.data)