# coding: utf-8

import autocomplete_light
from django.utils.translation import ugettext as _

from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

from . import models


class RegionAutocomplete(autocomplete_light.AutocompleteModelBase):
    model = models.Region
    choices = models.Region.objects
    search_fields = ['name', ]
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('Type some text to search'),
    }


class ProvinceAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['name']
    choices = models.Province.objects
    dependency_map = {
        'region': '#id_region',
    }

    # autocomplete 2.0
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('Type some text to search'),
    }

    model = models.Province


class LocalityAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['name']
    choices = models.Locality.objects
    dependency_map = {
        'province': '#id_province',
    }

    # autocomplete 2.0
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('Type some text to search'),
    }

    model = models.Locality


class ZipCodeAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['code']
    choices = models.ZipCode.objects
    dependency_map = {
        'locality': '#id_locality',
    }

    # autocomplete 2.0
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('Type some text to search'),
    }

    model = models.ZipCode


autocomplete_light.register(RegionAutocomplete)
autocomplete_light.register(ProvinceAutocomplete)
autocomplete_light.register(LocalityAutocomplete)
autocomplete_light.register(ZipCodeAutocomplete)
