# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


# APP DASHBOARD
class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        # Registered dashboards
        self.children.append(
            LocalityDashboard(),
        )


# LOCALITY DASHBOARDS
class LocalityDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Locality"),
            'display': "tabs",
            'children': [
                LocalityModel(),
            ]
        })
        super(LocalityDashboard, self).__init__(**kwargs)


# MODELS
class LocalityModel(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Locality"),
            'models': (
                'jmb.locality_it.models.Region',
                'jmb.locality_it.models.Province',
                'jmb.locality_it.models.Locality',
                'jmb.locality_it.models.ZipCode',
            ),
        }
        super(LocalityModel, self).__init__(**kwargs)





# Used in /admin
# jmb_dashboard.register_group(LocalityDashboard, 'jmb.locality_it_locality')
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.locality_it')
