# coding: utf-8

from django.contrib.auth.models import User
from django.core.management.base import BaseCommand
from django.core.files import File

from optparse import make_option

from jmb.core.admin.import_data import XlsFile

from jmb.locality_it import models


class ImportAddress(XlsFile):
    """
    Before running the command make sure you've imported regions, provinces and locality. if you have not already done
    so, you must run the commands import_region_province_from_xls and import_locality_from_xls.
    To import data from import_command_source execute:

    dj associate_cap_from_xls -f .src/jmb.locality_it/jmb/locality_it/management/commands/import_command_source/associate_cap.xlsx

    """
    def do(self, row, kw, j):
        zipcode, created = models.ZipCode.objects.get_or_create(code=row.CAP)
        try:
            locality = models.Locality.objects.get(istat_code=row.Istat)
        except models.Locality.DoesNotExist:
            print "località {} ({}) non trovata".format(row.Comune, row.Istat)
            return -1
        zipcode.locality.add(locality)


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
    )

    output_transaction = True

    def handle(self, *args, **options):
        filename = options.get('filename')
        if filename is not None:
            address_to_import = File(open(filename, 'r'))
            import_data = ImportAddress(
                file_contents=address_to_import.read(), auto=True)
            import_data.read()
        else:
            print "please indicate file to import with -f <file_name>"