# coding: utf-8
from django.contrib.auth.models import User
from django.core.management.base import BaseCommand
from django.core.files import File

from optparse import make_option

from jmb.core.admin.import_data import XlsFile

from jmb.locality_it import models


class ImportLocality(XlsFile):
    """
    Before running the command make sure you've imported regions and provinces. if you have not already done so, you
    must run the command import_region_province_from_xls.
    To import data from import_command_source execute:

    dj import_locality_from_xls -f .src/jmb.locality_it/jmb/locality_it/management/commands/import_command_source/import_locality.xlsx

    """

    def do(self, row, kw, j):
        locality, created = models.Locality.objects.get_or_create(istat_code=row.Istat)
        locality.name = row.Nome
        locality.code = row.Prog
        province = models.Province.objects.get(code=int(row.CodProvincia))
        locality.province = province
        locality.save()


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
    )

    output_transaction = True

    def handle(self, *args, **options):
        filename = options.get('filename')
        if filename is not None:
            address_to_import = File(open(filename, 'r'))
            import_data = ImportLocality(
                file_contents=address_to_import.read(), auto=True)
            import_data.read()
        else:
            print "please indicate file to import with -f <file_name>"